deeplake.api.read
=================
.. currentmodule:: deeplake.api.read
.. function:: read(path: str, verify: bool = False, creds: Optional[Dict] = None, compression: Optional[str] = None, storage: Optional[StorageProvider] = None) -> Sample

    See :func:`deeplake.read`.
